from setuptools import setup, find_packages

setup(
    name="sidra_helpers",
    version="1.0.1",
    author="Guilherme da Silva Frainer",
    author_email="guilherme.sfrainer@gmail.com",
    description="Helper functions made for personal use to work with the SIDRA API",
    url="https://github.com/GuilhermeFrainer/sidra_helpers",
    packages=find_packages(),
)